'use strict'

const util = require('util')
const exec = util.promisify(require('child_process').exec)

class JasperNode {

    constructor(resourcePath) {
        this.executable = __dirname + '/JasperStarter/bin/jasperstarter'
        this.resourcePath = resourcePath || null
    }
    
    process(inputFile, outputFile, parameters, format = 'pdf') {
        this.command = this.executable
        this.command += ' process '
        this.command += inputFile
        this.command += ' -o ' + outputFile
        this.command += ' -f ' + format

        if (this.resourcePath) {
            this.command += ' -r ' + this.resourcePath
        }

        this.command += ' -P'
        for (var key in parameters) {
            this.command += ` ${key}=${parameters[key]}`
        }

        return this
    }

    listParameters(inputFile) {
        this.command = this.executable
        this.command += ' list_parameters ' + inputFile
        return this
    }

    async output() {
        return this.command
    }

    async execute() {
        try {
            const output = await exec(this.command)
            return output.stdout
        } catch (e) {
            console.log(`Error JasperNode: ${e}`)
        }
    }

    static quotes(str) {
        return `\"${str}\"`
    }

    quotes(str) {
        return JasperNode.quotes(str)
    }

}

module.exports = JasperNode